@@ -17,7 +17,7 @@ from ladybug_geometry.geometry2d.polygon import Polygon2D
 from ladybug_geometry.geometry3d.pointvector import Vector3D, Point3D
 from ladybug_geometry.geometry3d.plane import Plane
 from ladybug_geometry.geometry3d.face import Face3D
-from ladybug_geometry_polyskel.polyskel import sub_polygons
+from ladybug_geometry_polyskel.polysplit import perimeter_core_subpolygons
 
 try:
     from itertools import izip as zip  # python 2
@@ -731,20 +731,20 @@ class Building(_BaseGeometry):
             assert perim_offset > 0, 'perimeter_offset cannot be less than than 0.'
             new_face3d_array = []
             for floor_face in face3d_array:
-                if floor_face.has_holes:
-                    # TODO: Remove this once holes have been implemented in polyskel
-                    new_face3d_array.append(floor_face)
+                if floor_face.has_holes:  # holes are not managed well in polyskel
+                    new_face3d_array.append(floor_face)  # just use existing floor
                 else:
                     z_val = floor_face[0].z
-                    base_poly = Polygon2D(
-                        [Point2D(pt.x, pt.y) for pt in floor_face.vertices])
-                    if base_poly.is_clockwise:
-                        base_poly = base_poly.reverse()
-                    sub_polys_perim, sub_polys_core = sub_polygons(
-                        polygon=base_poly, distance=perim_offset, tol=tolerance)
-                    for s_poly in sub_polys_perim + sub_polys_core:
-                        sub_face = Face3D([Point3D(pt.x, pt.y, z_val) for pt in s_poly])
-                        new_face3d_array.append(sub_face)
+                    base_p = Polygon2D([Point2D(p.x, p.y) for p in floor_face.boundary])
+                    try:
+                        sub_polys_perim, sub_polys_core = perimeter_core_subpolygons(
+                            polygon=base_p, distance=perim_offset, tol=tolerance)
+                        for s_poly in sub_polys_perim + sub_polys_core:
+                            sub_face = Face3D([Point3D(pt.x, pt.y, z_val) for pt in s_poly])
+                            new_face3d_array.append(sub_face)
+                    except Exception as e:
+                        print(e)  # the generation of the polyskel failed
+                        new_face3d_array.append(floor_face)  # just use existing floor
             face3d_array = new_face3d_array  # replace with offset core/perimeter
 
         # create the Room2D objects
