@@ -8,6 +8,7 @@ import dragonfly.windowparameter as glzpar
 from dragonfly.windowparameter import _WindowParameterBase, _AsymmetricBase
 import dragonfly.shadingparameter as shdpar
 from dragonfly.shadingparameter import _ShadingParameterBase
+import dragonfly.writer.room2d as writer
 
 from honeybee.typing import float_positive, clean_string
 import honeybee.boundarycondition as hbc
@@ -281,7 +282,7 @@ class Room2D(_BaseGeometry):
             if window_parameters is not None:
                 new_win_pars = []
                 for seg, win_par in zip(polygon.segments, reversed(window_parameters)):
-                    if isinstance (win_par, _AsymmetricBase):
+                    if isinstance(win_par, _AsymmetricBase):
                         new_win_pars.append(win_par.flip(seg.length))
                     else:
                         new_win_pars.append(win_par)
@@ -629,7 +630,7 @@ class Room2D(_BaseGeometry):
                 'Window parameters do not match between adjacent Room2Ds "{}" and ' \
                 '"{}".'.format(self.identifier, other_room_2d.identifier)
 
-    def set_boundary_condition(self, self_seg_index, boundary_condition):
+    def set_boundary_condition(self, seg_index, boundary_condition):
         """Set a single segment of this Room2D to have a certain boundary condition.
 
         Args:
@@ -639,7 +640,10 @@ class Room2D(_BaseGeometry):
         """
         assert boundary_condition in bcs, \
             'Expected boundary condition. Got {}.'.format(type(boundary_condition))
-        self._boundary_conditions[self_seg_index] = boundary_condition
+        if self._window_parameters[seg_index] is not None:
+            assert isinstance(boundary_condition, (Outdoors, Surface)), '{} cannot be ' \
+                'assigned to a wall with windows.'.format(boundary_condition)
+        self._boundary_conditions[seg_index] = boundary_condition
 
     def move(self, moving_vec):
         """Move this Room2D along a vector.
@@ -743,9 +747,9 @@ class Room2D(_BaseGeometry):
         """
         new_geo = self.floor_geometry.remove_colinear_vertices(tolerance)
         rebuilt_room = Room2D(
-                self.identifier, new_geo, self.floor_to_ceiling_height,
-                is_ground_contact=self.is_ground_contact,
-                is_top_exposed=self.is_top_exposed)
+            self.identifier, new_geo, self.floor_to_ceiling_height,
+            is_ground_contact=self.is_ground_contact,
+            is_top_exposed=self.is_top_exposed)
         rebuilt_room._display_name = self.display_name
         rebuilt_room._user_data = self._user_data
         rebuilt_room._parent = self._parent
@@ -765,7 +769,7 @@ class Room2D(_BaseGeometry):
                 floor_to_ceiling_height at which adjacent Faces will be split.
                 This is also used in the generation of Windows. Default: 0.01,
                 suitable for objects in meters.
-        
+
         Returns:
             A tuple with the two items below.
 
@@ -811,7 +815,9 @@ class Room2D(_BaseGeometry):
                             adjacencies[i] = (face, adj[1])
                             break
 
-        # set the multiplier, display_name, and user_data
+        # set the story, multiplier, display_name, and user_data
+        if self.has_parent:
+            hb_room.story = self.parent.identifier
         hb_room.multiplier = multiplier
         hb_room._display_name = self._display_name
         hb_room._user_data = self._user_data
@@ -882,6 +888,14 @@ class Room2D(_BaseGeometry):
 
         return base
 
+    @property
+    def to(self):
+        """Room2D writer object.
+
+        Use this method to access Writer class to write the room2d in other formats.
+        """
+        return writer
+
     @staticmethod
     def solve_adjacency(room_2ds, tolerance=0.01):
         """Solve for all adjacencies between a list of input Room2Ds.
@@ -1026,7 +1040,7 @@ class Room2D(_BaseGeometry):
         for i, seg in enumerate(original_geo.boundary_segments):
             new_bcs.append(bcs[i])
             win_par = win_pars[i]
-            if isinstance (win_par, _AsymmetricBase):
+            if isinstance(win_par, _AsymmetricBase):
                 new_win_pars.append(win_par.flip(seg.length))
             else:
                 new_win_pars.append(win_par)
@@ -1037,7 +1051,7 @@ class Room2D(_BaseGeometry):
         new_win_pars.reverse()
         new_shd_pars.reverse()
 
-         # add any objects related to the holes
+        # add any objects related to the holes
         if original_geo.has_holes:
             bound_len = len(original_geo.boundary)
             new_bcs = new_bcs + bcs[bound_len:]
